import click
from importlib import metadata
from cookiecutter.main import cookiecutter


@click.group()
def plugin():
    """Commands for Takanori CLI plugin."""
    pass


@plugin.command()
@click.option(
    "-t",
    "--template",
    default="https://github.com/takavfx/takanori-cli-plugin-template.git",
    help="Option template to create a plugin package.",
)
def create(template: str):
    """Create Takanori CLI plugin."""
    cookiecutter(template)


@plugin.command()
def info():
    """Display loadable Takanori CLI plugins."""
    eps = metadata.entry_points()
    if eps.get("takanoricli"):
        mycli_eps = eps["takanoricli"]
        for ep in mycli_eps:
            print("+", ep.name, "=", ep.value)
    else:
        print("- Coudn't find any Takanori CLI plugins.")



import click

from takanori_cli import __version__
from .create import mkdd
from .plugin import plugin


@click.group()
@click.version_option(version=__version__, prog_name="Takanori CLI")
def main():
    pass


def register_cmds():
    cmds = [mkdd, plugin]

    for cmd in cmds:
        main.add_command(cmd)


def cli():
    from importlib import metadata

    eps = metadata.entry_points()
    if eps.get("takanoricli"):
        mycli_eps = eps["takanoricli"]
        for ep in mycli_eps:
            plugin = ep.load()
            main.add_command(plugin)
    register_cmds()
    main()



import click
import datetime
from pathlib import Path


@click.command()
@click.argument("target", default=".")
@click.option("-d", "--days", default=0, help="Delta days from today's date.")
@click.option("-s", "--silent", is_flag=True, help="Execute command without confirm.")
def mkdd(target: str, days: int, silent: bool):
    """Make date directories to a given path."""
    target_path = Path(target)

    today = datetime.date.today() + datetime.timedelta(days=days)
    year = str(today.year)
    month = str(today.month)
    day = str(today.day)

    year_dir = target_path.joinpath(year)
    month_dir = year_dir.joinpath(month)
    day_dir = month_dir.joinpath(day)

    if not silent:
        print("Preview :: ", day_dir.absolute())
        click.confirm('Do you want to continue?', default=True, abort=True)

    day_dir.mkdir(parents=True)
